@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use Moo;
 use POSIX qw( ceil );
 
-our $VERSION = '0.0107';
+our $VERSION = '0.0200';
 
 use constant K => 3.14159265358979323846 / 180;
 
@@ -92,19 +92,13 @@ sub pen_down {
 }
 
 
-sub turn {
+sub right {
     my $self = shift;
     my $degrees = shift // 0;
     $self->heading( ( $self->heading + $degrees ) % 360 );
 }
 
 
-sub right {
-    my $self = shift;
-    $self->turn(@_);
-}
-
-
 sub left {
     my $self = shift;
     my $degrees = shift // 0;
@@ -203,14 +197,14 @@ Data::Turtle - Turtle Movement and State Operations
 
 =head1 VERSION
 
-version 0.0107
+version 0.0200
 
 =head1 SYNOPSIS
 
   use Data::Turtle;
   my $turtle = Data::Turtle->new;
   $turtle->pen_up;
-  $turtle->turn(45);
+  $turtle->right(45);
   $turtle->forward(10);
   $turtle->goto(100, 100);
   $turtle->mirror;
@@ -306,12 +300,6 @@ Raise the pen head to stop drawing.
 
 Lower the pen head to begin drawing.
 
-=head2 turn
-
-  $turtle->right($degrees);
-
-Set the heading to the given degrees.
-
 =head2 right
 
   $turtle->right($degrees);
